@@ -1,7 +1,7 @@
 from dbgettext.registry import registry, Options
 from dbgettext.lexicons import html
 
-from models import Category, Forum
+from forums.models import Category, Forum
 
 
 class CategoryOptions(Options):
@@ -11,4 +11,5 @@ class ForumOptions(Options):
     attributes = ('name')
     parsed_attributes = {'description': html.lexicon}
 
-registry.register(Category, CategoryOptions)
\ No newline at end of file
+registry.register(Category, CategoryOptions)
+registry.register(Forum, ForumOptions)
